summaryrefslogtreecommitdiffstats
path: root/kplato/kpttaskdialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'kplato/kpttaskdialog.h')
-rw-r--r--kplato/kpttaskdialog.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kplato/kpttaskdialog.h b/kplato/kpttaskdialog.h
index 169aec6b..2e6c1586 100644
--- a/kplato/kpttaskdialog.h
+++ b/kplato/kpttaskdialog.h
@@ -64,9 +64,9 @@ public:
* @param accounts all defined accounts
* @param workTime defines the number of hours pr day and week
* @param baseline if true, project is baselined
* @param tqparent tqparent widget
*/
- TaskDialog(Task &task, Accounts &accounts, StandardWorktime *workTime=0, bool baseline=false, TQWidget *tqparent=0);
+ TaskDialog(Task &task, Accounts &accounts, StandardWorktime *workTime=0, bool baseline=false, TQWidget *parent=0);
KCommand *buildCommand(Part *part);
@@ -64,9 +64,9 @@ public:
* @param workTime defines the number of hours pr day and week
* @param baseline if true, project is baselined
- * @param tqparent tqparent widget
+ * @param parent parent widget
*/